==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/PodNetworkConnectivityCheckStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodNetworkConnectivityCheckStatusBuilder extends PodNetworkConnectivityCheckStatusFluentImpl<PodNetworkConnectivityCheckStatusBuilder> implements VisitableBuilder<PodNetworkConnectivityCheckStatus,PodNetworkConnectivityCheckStatusBuilder>{
  public PodNetworkConnectivityCheckStatusBuilder() {
    this(false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(Boolean validationEnabled) {
    this(new PodNetworkConnectivityCheckStatus(), validationEnabled);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodNetworkConnectivityCheckStatus(), validationEnabled);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,PodNetworkConnectivityCheckStatus instance) {
    this(fluent, instance, false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,PodNetworkConnectivityCheckStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withFailures(instance.getFailures());
      fluent.withOutages(instance.getOutages());
      fluent.withSuccesses(instance.getSuccesses());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatus instance) {
    this(instance,false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withFailures(instance.getFailures());
      this.withOutages(instance.getOutages());
      this.withSuccesses(instance.getSuccesses());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodNetworkConnectivityCheckStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PodNetworkConnectivityCheckStatus build() {
    PodNetworkConnectivityCheckStatus buildable = new PodNetworkConnectivityCheckStatus(fluent.getConditions(),fluent.getFailures(),fluent.getOutages(),fluent.getSuccesses());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/PodNetworkConnectivityCheckStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodNetworkConnectivityCheckStatusBuilder extends PodNetworkConnectivityCheckStatusFluent<PodNetworkConnectivityCheckStatusBuilder> implements VisitableBuilder<PodNetworkConnectivityCheckStatus,PodNetworkConnectivityCheckStatusBuilder>{
  public PodNetworkConnectivityCheckStatusBuilder() {
    this(false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(Boolean validationEnabled) {
    this(new PodNetworkConnectivityCheckStatus(), validationEnabled);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodNetworkConnectivityCheckStatus(), validationEnabled);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,PodNetworkConnectivityCheckStatus instance) {
    this(fluent, instance, false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatusFluent<?> fluent,PodNetworkConnectivityCheckStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodNetworkConnectivityCheckStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withFailures(instance.getFailures());
      fluent.withOutages(instance.getOutages());
      fluent.withSuccesses(instance.getSuccesses());
      fluent.withConditions(instance.getConditions());
      fluent.withFailures(instance.getFailures());
      fluent.withOutages(instance.getOutages());
      fluent.withSuccesses(instance.getSuccesses());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatus instance) {
    this(instance,false);
  }
  public PodNetworkConnectivityCheckStatusBuilder(PodNetworkConnectivityCheckStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodNetworkConnectivityCheckStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withFailures(instance.getFailures());
      this.withOutages(instance.getOutages());
      this.withSuccesses(instance.getSuccesses());
      this.withConditions(instance.getConditions());
      this.withFailures(instance.getFailures());
      this.withOutages(instance.getOutages());
      this.withSuccesses(instance.getSuccesses());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodNetworkConnectivityCheckStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PodNetworkConnectivityCheckStatus build() {
    PodNetworkConnectivityCheckStatus buildable = new PodNetworkConnectivityCheckStatus(fluent.buildConditions(),fluent.buildFailures(),fluent.buildOutages(),fluent.buildSuccesses());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
